@@ -9,7 +9,7 @@
 //!
 //! This library assumes that the `client_encoding` backend parameter has been
 //! set to `UTF8`. It will most likely not behave properly if that is not the case.
-#![doc(html_root_url="https://sfackler.github.io/rust-postgres-protocol/doc/v0.1.0")]
+#![doc(html_root_url="https://sfackler.github.io/rust-postgres-protocol/doc/v0.1.1")]
 #![warn(missing_docs)]
 extern crate byteorder;
 extern crate fallible_iterator;
@@ -17,7 +17,7 @@ extern crate hex;
 extern crate md5;
 
 use byteorder::{WriteBytesExt, BigEndian};
-use std::io::{self, Cursor};
+use std::io;
 
 pub mod authentication;
 pub mod message;
@@ -45,7 +45,7 @@ fn write_nullable<F, E>(serializer: F, buf: &mut Vec<u8>) -> Result<(), E>
         IsNull::No => try!(i32::from_usize(buf.len() - base - 4)),
         IsNull::Yes => -1,
     };
-    Cursor::new(&mut buf[base..base + 4]).write_i32::<BigEndian>(size).unwrap();
+    (&mut buf[base..base + 4]).write_i32::<BigEndian>(size).unwrap();
 
     Ok(())
 }
